pub struct ListNotebookSessionsFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to ListNotebookSessions.
Lists, in descending order, the sessions that have been created in a notebook that are in an active state like CREATING, CREATED, IDLE or BUSY. Newer sessions are listed first; older sessions are listed later.
Implementations
Sourceimpl ListNotebookSessionsFluentBuilder
impl ListNotebookSessionsFluentBuilder
Sourcepub fn as_input(&self) -> &ListNotebookSessionsInputBuilder
pub fn as_input(&self) -> &ListNotebookSessionsInputBuilder
Access the ListNotebookSessions as a reference.
Sourcepub async fn send(
self,
) -> Result<ListNotebookSessionsOutput, SdkError<ListNotebookSessionsError, HttpResponse>>
pub async fn send( self, ) -> Result<ListNotebookSessionsOutput, SdkError<ListNotebookSessionsError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<ListNotebookSessionsOutput, ListNotebookSessionsError, Self>
pub fn customize( self, ) -> CustomizableOperation<ListNotebookSessionsOutput, ListNotebookSessionsError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn notebook_id(self, input: impl Into<String>) -> Self
pub fn notebook_id(self, input: impl Into<String>) -> Self
The ID of the notebook to list sessions for.
Sourcepub fn set_notebook_id(self, input: Option<String>) -> Self
pub fn set_notebook_id(self, input: Option<String>) -> Self
The ID of the notebook to list sessions for.
Sourcepub fn get_notebook_id(&self) -> &Option<String>
pub fn get_notebook_id(&self) -> &Option<String>
The ID of the notebook to list sessions for.
Sourcepub fn max_results(self, input: i32) -> Self
pub fn max_results(self, input: i32) -> Self
The maximum number of notebook sessions to return.
Sourcepub fn set_max_results(self, input: Option<i32>) -> Self
pub fn set_max_results(self, input: Option<i32>) -> Self
The maximum number of notebook sessions to return.
Sourcepub fn get_max_results(&self) -> &Option<i32>
pub fn get_max_results(&self) -> &Option<i32>
The maximum number of notebook sessions to return.
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.