#[non_exhaustive]pub struct ListNotebookSessionsInputBuilder { /* private fields */ }Expand description
A builder for ListNotebookSessionsInput.
Implementations
Sourceimpl ListNotebookSessionsInputBuilder
impl ListNotebookSessionsInputBuilder
Sourcepub fn notebook_id(self, input: impl Into<String>) -> Self
pub fn notebook_id(self, input: impl Into<String>) -> Self
The ID of the notebook to list sessions for.
This field is required.Sourcepub fn set_notebook_id(self, input: Option<String>) -> Self
pub fn set_notebook_id(self, input: Option<String>) -> Self
The ID of the notebook to list sessions for.
Sourcepub fn get_notebook_id(&self) -> &Option<String>
pub fn get_notebook_id(&self) -> &Option<String>
The ID of the notebook to list sessions for.
Sourcepub fn max_results(self, input: i32) -> Self
pub fn max_results(self, input: i32) -> Self
The maximum number of notebook sessions to return.
Sourcepub fn set_max_results(self, input: Option<i32>) -> Self
pub fn set_max_results(self, input: Option<i32>) -> Self
The maximum number of notebook sessions to return.
Sourcepub fn get_max_results(&self) -> &Option<i32>
pub fn get_max_results(&self) -> &Option<i32>
The maximum number of notebook sessions to return.
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourcepub fn build(self) -> Result<ListNotebookSessionsInput, BuildError>
pub fn build(self) -> Result<ListNotebookSessionsInput, BuildError>
Consumes the builder and constructs a ListNotebookSessionsInput.
Sourceimpl ListNotebookSessionsInputBuilder
impl ListNotebookSessionsInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<ListNotebookSessionsOutput, SdkError<ListNotebookSessionsError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<ListNotebookSessionsOutput, SdkError<ListNotebookSessionsError, HttpResponse>>
Sends a request with this input using the given client.