#[non_exhaustive]pub struct ListNotebookSessionsOutputBuilder { /* private fields */ }Expand description
A builder for ListNotebookSessionsOutput.
Implementations
Sourceimpl ListNotebookSessionsOutputBuilder
impl ListNotebookSessionsOutputBuilder
Sourcepub fn notebook_sessions_list(self, input: NotebookSessionSummary) -> Self
pub fn notebook_sessions_list(self, input: NotebookSessionSummary) -> Self
Appends an item to notebook_sessions_list.
To override the contents of this collection use set_notebook_sessions_list.
A list of the sessions belonging to the notebook.
Sourcepub fn set_notebook_sessions_list(
self,
input: Option<Vec<NotebookSessionSummary>>,
) -> Self
pub fn set_notebook_sessions_list( self, input: Option<Vec<NotebookSessionSummary>>, ) -> Self
A list of the sessions belonging to the notebook.
Sourcepub fn get_notebook_sessions_list(&self) -> &Option<Vec<NotebookSessionSummary>>
pub fn get_notebook_sessions_list(&self) -> &Option<Vec<NotebookSessionSummary>>
A list of the sessions belonging to the notebook.
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourcepub fn build(self) -> Result<ListNotebookSessionsOutput, BuildError>
pub fn build(self) -> Result<ListNotebookSessionsOutput, BuildError>
Consumes the builder and constructs a ListNotebookSessionsOutput.
This method will fail if any of the following fields are not set: